/*******************************************************************************
 * Copyright (c) 2013 IBM Corp.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * and Eclipse Distribution License v1.0 which accompany this distribution.
 *
 * The Eclipse Public License is available at
 *    http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 *   http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *    Takahiro Inaba - initial API and implementation and/or initial
 *                     documentation
 *******************************************************************************/
package com.ibm.jmeter.protocol.mqtt;

import org.eclipse.paho.client.mqttv3.MqttClient;
import org.eclipse.paho.client.mqttv3.MqttPersistenceException;
import org.eclipse.paho.client.mqttv3.MqttSecurityException;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;

public class MqttOverTcpIpClient implements IMqttClient {
	private MqttClient client;

	public MqttOverTcpIpClient(String serverURI, String clientId) throws MqttException {
		try {
			// The message persistence is ignored.
			client = new MqttClient(serverURI, clientId, new MemoryPersistence());
		} catch (org.eclipse.paho.client.mqttv3.MqttException e) {
			throw new MqttException(e);
		}
	}

	@Override
	public void connect() throws MqttException {
		try {
			client.connect();
		} catch (MqttSecurityException e) {
			throw new MqttException(e);
		} catch (org.eclipse.paho.client.mqttv3.MqttException e) {
			throw new MqttException(e);
		}
	}

	@Override
	public void close() throws MqttException {
		if (client != null) {
			try {
				client.disconnect();
				client.close();
			} catch (org.eclipse.paho.client.mqttv3.MqttException e) {
				throw new MqttException(e);
			}
		}
	}

	@Override
	public boolean isConnected() {
		return client.isConnected();
	}

	@Override
	public void publish(String topicString, MqttMessage message) throws MqttException {
		org.eclipse.paho.client.mqttv3.MqttMessage msg
			= new org.eclipse.paho.client.mqttv3.MqttMessage(message.getMessageBody());
		msg.setQos(message.getQos());
		msg.setRetained(message.isRetained());
		try {
			client.publish(topicString, msg);
		} catch (MqttPersistenceException e) {
			throw new MqttException(e);
		} catch (org.eclipse.paho.client.mqttv3.MqttException e) {
			throw new MqttException(e);
		}
	}

	@Override
	public String getClientId() {
		return client.getClientId();
	}

}
